@@ -40,6 +40,8 @@ class App:
             request_queue_size=500,
             server_name=socket.gethostname()
         )
+        
+        self._create_defaults()
 
     def wsgi_app(self, environ, start_response):
         request = Request(environ)
@@ -126,6 +128,12 @@ class App:
         self.templates_env = Environment(
             loader=FileSystemLoader(os.path.abspath(templates_dir)))
         self.templates_dir = templates_dir
+    
+    def create_defaults(self):
+        os.mkdir("apppages")
+        with open(f'{os.path.abspath("apppages")}/error404.html', "w") as f:
+            f.write("...")
+            
 
     def run(self):
         try:
